﻿using System;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using System.Text.RegularExpressions;

namespace Cafe.AddWindows
{
    public partial class AddEmployeeWindow : Window
    {
        public AddEmployeeWindow()
        {
            InitializeComponent();
            RoleBox.ItemsSource = Connection.db.Roles.Select(item => item.RoleName).ToList();
        }

        private void RegistrationClick(object sender, RoutedEventArgs e)
        {
            bool regRes = Registration(Login.Text.ToString(), Password.Password.ToString(), FirstName.Text.ToString(),
                                        SecondName.Text.ToString(), MiddleName.Text.ToString(), Email.Text.ToString());

            if (regRes)
            {
                MainWindow mainWindow = new MainWindow();
                mainWindow.Show();
                this.Close();
            }
        }

        public bool Registration(string login, string password, string Fname, string Sname, string Mname, string email)
        {
            if (Login.Text == "" || Password.Password == "" || FirstName.Text == "" || SecondName.Text == "" || Email.Text == "" || RoleBox.SelectedItem == null)
            {
                ErrorWindow errorWindow = new ErrorWindow("пустые поля");
                errorWindow.Show();
                return false;
            }
            if (Connection.db.Users.Select(item => item.Login).Contains(Login.Text))
            {
                ErrorWindow errorWindow = new ErrorWindow("такой пользователь уже существует");
                errorWindow.Show();
                return false;
            }
            if (!IsValidEmail(Email.Text))
            {
                ErrorWindow errorWindow = new ErrorWindow("неверный формат почты");
                errorWindow.Show();
                return false;
            }

            string roleName = Convert.ToString(RoleBox.SelectedItem);
            Roles role = Connection.db.Roles.Where(item => item.RoleName == roleName).FirstOrDefault();

            Users user = new Users()
            {
                Login = Login.Text,
                Password = Encrypt.Hash(Password.Password),
                SecondName = SecondName.Text,
                FirstName = FirstName.Text,
                Email = Email.Text,
                IDRole = role.ID,
                IsFired = false
            };
            if (MiddleName.Text != "")
            {
                user.MiddleName = MiddleName.Text;
            }

            Connection.db.Users.Add(user);
            Connection.db.SaveChanges();

            return true;
        }

        private void BackButtonClick(object sender, RoutedEventArgs e)
        {
            MainWindow mainWindow = new MainWindow();
            mainWindow.Show();
            this.Close();
        }

        private bool IsValidEmail(string email)
        {
            string regex = @"^([\w\.\-]+)@([\w\-]+)((\.(\w){2,3})+)$";
            if (Regex.IsMatch(email, regex))
                return true;
            else
                return false;
        }

        private void TextChanged(object sender, TextChangedEventArgs e)
        {
            if (Regex.IsMatch((((TextBox)sender).Text).ToString(), "[^А-я-:]"))
            {
                ((TextBox)sender).Text = ((TextBox)sender).Text.Remove(((TextBox)sender).Text.Length - 1);
                ((TextBox)sender).SelectionStart = ((TextBox)sender).Text.Length;
            }
        }
    }
}